package pm;

import java.util.*;
import javax.ejb.*;
import javax.persistence.*;

@Stateless
@Remote(PocketMoneyService.class)
public class PocketMoneyServiceBean implements PocketMoneyService, java.io.Serializable {
	@PersistenceContext
	private EntityManager em;

	public int createAccount(String owner) {
		PocketMoney p = new PocketMoney(owner, 0);
		em.persist(p);
		return p.getId();
	}

	public int createCategory(String name) {
		Category c = new Category(name);
		em.persist(c);
		return c.getId();
	}

	public void deposit(int pid, int amount, String reason, int cid) {
		PocketMoney p = this.findPocketMoney(pid);
		p.deposit(amount, reason, this.findCategory(cid));
	}

	public void payment(int pid, int amount, String reason, int cid) {
		PocketMoney p = this.findPocketMoney(pid);
		p.payment(amount, reason, this.findCategory(cid));
	}

	public void removeAccount(int pid) {
		PocketMoney p = this.findPocketMoney(pid);
		em.remove(p);
	}

	public List<PocketMoney> searchAccount(String owner) {
		return em.createQuery("SELECT p FROM PocketMoney p WHERE p.owner LIKE :owner").setParameter("owner", owner).setMaxResults(8).getResultList(); 
	}

	public List<PocketMoneyLine> searchLineByCategory(String name) {
		return em.createQuery("SELECT l FROM PocketMoneyLine l, IN(l.category) c WHERE c.name = :name").setParameter("name", name).setMaxResults(8).getResultList(); 
	}

	protected PocketMoney findPocketMoney(int id) {
		return (PocketMoney) em.find(PocketMoney.class, id);
	}

	protected Category findCategory(int id) {
		return (Category) em.find(Category.class, id);
	}
}
